summaryrefslogtreecommitdiff
path: root/include/uapi/drm/xe_drm.h
diff options
context:
space:
mode:
authorRodrigo Vivi <rodrigo.vivi@intel.com>2023-11-14 16:34:34 +0300
committerRodrigo Vivi <rodrigo.vivi@intel.com>2023-12-21 19:44:38 +0300
commitaaa115ffaa467782b01cfa81711424315823bdb5 (patch)
treebea90b8bed257adfd399af177457815b62e3a4ac /include/uapi/drm/xe_drm.h
parent4a349c86110a6fab26ce5f4fcb545acf214efed5 (diff)
downloadlinux-aaa115ffaa467782b01cfa81711424315823bdb5.tar.xz
drm/xe/uapi: Be more specific about the vm_bind prefetch region
Let's bring a bit of clarity on this 'region' field that is part of vm_bind operation struct. Rename and document to make it more than obvious that it is a region instance and not a mask and also that it should only be used with the prefetch operation itself. Signed-off-by: Rodrigo Vivi <rodrigo.vivi@intel.com> Signed-off-by: Francois Dugast <francois.dugast@intel.com> Reviewed-by: Matt Roper <matthew.d.roper@intel.com>
Diffstat (limited to 'include/uapi/drm/xe_drm.h')
-rw-r--r--include/uapi/drm/xe_drm.h8
1 files changed, 6 insertions, 2 deletions
diff --git a/include/uapi/drm/xe_drm.h b/include/uapi/drm/xe_drm.h
index b2bd76efd940..88f3aca02b08 100644
--- a/include/uapi/drm/xe_drm.h
+++ b/include/uapi/drm/xe_drm.h
@@ -673,8 +673,12 @@ struct drm_xe_vm_bind_op {
/** @flags: Bind flags */
__u32 flags;
- /** @mem_region: Memory region to prefetch VMA to, instance not a mask */
- __u32 region;
+ /**
+ * @prefetch_mem_region_instance: Memory region to prefetch VMA to.
+ * It is a region instance, not a mask.
+ * To be used only with %DRM_XE_VM_BIND_OP_PREFETCH operation.
+ */
+ __u32 prefetch_mem_region_instance;
/** @reserved: Reserved */
__u64 reserved[2];